@@ -1,5 +1,5 @@
 package Yahoo::Marketing::APT::ApprovalTask;
-# Copyright (c) 2008 Yahoo! Inc.  All rights reserved.  
+# Copyright (c) 2009 Yahoo! Inc.  All rights reserved.  
 # The copyrights to the contents of this file are licensed under the Perl Artistic License (ver. 15 Aug 1997) 
 
 use strict; use warnings;
@@ -17,17 +17,19 @@ sub _user_setable_attributes {
                  ID
                  accountID
                  approvalID
+                 approvalObject
+                 approvalTrigger
                  assignedToUserID
                  blockerApprovalTaskID
                  comment
+                 createTimestamp
+                 lastUpdateTimestamp
                  status
             /  );
 }
 
 sub _read_only_attributes {
     return ( qw/
-                 createTimestamp
-                 lastUpdateTimestamp
            / );
 }
 
@@ -39,7 +41,7 @@ __PACKAGE__->mk_accessors( __PACKAGE__->_user_setable_attributes,
 1;
 =head1 SYNOPSIS
 
-See L<http://help.yahoo.com/l/us/yahoo/amp/webservices/reference/data/> for documentation of the various data objects.
+See L<http://help.yahoo.com/l/us/yahoo/apt/webservices/reference/data/> for documentation of the various data objects.
 
 
 =cut
@@ -57,9 +59,13 @@ Creates a new instance
     ID
     accountID
     approvalID
+    approvalObject
+    approvalTrigger
     assignedToUserID
     blockerApprovalTaskID
     comment
+    createTimestamp
+    lastUpdateTimestamp
     status
 
 =back
@@ -68,8 +74,6 @@ Creates a new instance
 
 =over 8
 
-    createTimestamp
-    lastUpdateTimestamp
 
 =back
 
