@@ -1,5 +1,5 @@
 package Yahoo::Marketing::APT::BaseRate;
-# Copyright (c) 2008 Yahoo! Inc.  All rights reserved.  
+# Copyright (c) 2009 Yahoo! Inc.  All rights reserved.  
 # The copyrights to the contents of this file are licensed under the Perl Artistic License (ver. 15 Aug 1997) 
 
 use strict; use warnings;
@@ -23,7 +23,7 @@ sub _user_setable_attributes {
                  startDate
                  targetCPM
                  targetFloorPercentageMarkup
-                 targetingAttributeDescriptors
+                 targetingAttributeDescriptorsWithAny
             /  );
 }
 
@@ -40,7 +40,7 @@ __PACKAGE__->mk_accessors( __PACKAGE__->_user_setable_attributes,
 1;
 =head1 SYNOPSIS
 
-See L<http://help.yahoo.com/l/us/yahoo/amp/webservices/reference/data/> for documentation of the various data objects.
+See L<http://help.yahoo.com/l/us/yahoo/apt/webservices/reference/data/> for documentation of the various data objects.
 
 
 =cut
@@ -64,7 +64,7 @@ Creates a new instance
     startDate
     targetCPM
     targetFloorPercentageMarkup
-    targetingAttributeDescriptors
+    targetingAttributeDescriptorsWithAny
 
 =back
 
