@@ -1,5 +1,5 @@
 package Yahoo::Marketing::APT::CustomSegmentDescriptor;
-# Copyright (c) 2008 Yahoo! Inc.  All rights reserved.  
+# Copyright (c) 2009 Yahoo! Inc.  All rights reserved.  
 # The copyrights to the contents of this file are licensed under the Perl Artistic License (ver. 15 Aug 1997) 
 
 use strict; use warnings;
@@ -16,6 +16,7 @@ sub _user_setable_attributes {
     return ( qw/ 
                  ID
                  accountID
+                 description
                  name
             /  );
 }
@@ -33,7 +34,7 @@ __PACKAGE__->mk_accessors( __PACKAGE__->_user_setable_attributes,
 1;
 =head1 SYNOPSIS
 
-See L<http://help.yahoo.com/l/us/yahoo/amp/webservices/reference/data/> for documentation of the various data objects.
+See L<http://help.yahoo.com/l/us/yahoo/apt/webservices/reference/data/> for documentation of the various data objects.
 
 
 =cut
@@ -50,6 +51,7 @@ Creates a new instance
 
     ID
     accountID
+    description
     name
 
 =back
