@@ -1,5 +1,5 @@
 package Yahoo::Marketing::APT::Link;
-# Copyright (c) 2008 Yahoo! Inc.  All rights reserved.  
+# Copyright (c) 2009 Yahoo! Inc.  All rights reserved.  
 # The copyrights to the contents of this file are licensed under the Perl Artistic License (ver. 15 Aug 1997) 
 
 use strict; use warnings;
@@ -15,21 +15,23 @@ Yahoo::Marketing::APT::Link - a data object to represent a Link.
 sub _user_setable_attributes {
     return ( qw/ 
                  ID
+                 activationTimestamp
                  buyerDetails
+                 createTimestamp
+                 currency
                  guaranteedDeal
+                 lastUpdateTimestamp
                  nonGuaranteedDeal
                  paymentTermsInDays
                  sellerDetails
                  status
+                 timezone
                  type
             /  );
 }
 
 sub _read_only_attributes {
     return ( qw/
-                 activationTimestamp
-                 createTimestamp
-                 lastUpdateTimestamp
            / );
 }
 
@@ -41,7 +43,7 @@ __PACKAGE__->mk_accessors( __PACKAGE__->_user_setable_attributes,
 1;
 =head1 SYNOPSIS
 
-See L<http://help.yahoo.com/l/us/yahoo/amp/webservices/reference/data/> for documentation of the various data objects.
+See L<http://help.yahoo.com/l/us/yahoo/apt/webservices/reference/data/> for documentation of the various data objects.
 
 
 =cut
@@ -57,12 +59,17 @@ Creates a new instance
 =over 8
 
     ID
+    activationTimestamp
     buyerDetails
+    createTimestamp
+    currency
     guaranteedDeal
+    lastUpdateTimestamp
     nonGuaranteedDeal
     paymentTermsInDays
     sellerDetails
     status
+    timezone
     type
 
 =back
@@ -71,9 +78,6 @@ Creates a new instance
 
 =over 8
 
-    activationTimestamp
-    createTimestamp
-    lastUpdateTimestamp
 
 =back
 
