@@ -1,5 +1,5 @@
 package Yahoo::Marketing::APT::Placement;
-# Copyright (c) 2008 Yahoo! Inc.  All rights reserved.  
+# Copyright (c) 2009 Yahoo! Inc.  All rights reserved.  
 # The copyrights to the contents of this file are licensed under the Perl Artistic License (ver. 15 Aug 1997) 
 
 use strict; use warnings;
@@ -17,18 +17,21 @@ sub _user_setable_attributes {
                  ID
                  accountID
                  adGroupID
+                 createTimestamp
+                 discounts
                  endDate
                  guaranteedSettings
+                 lastUpdateTimestamp
                  nonGuaranteedSettings
                  startDate
                  status
+                 transferedFromID
+                 transferedToID
             /  );
 }
 
 sub _read_only_attributes {
     return ( qw/
-                 createTimestamp
-                 lastUpdateTimestamp
            / );
 }
 
@@ -40,7 +43,7 @@ __PACKAGE__->mk_accessors( __PACKAGE__->_user_setable_attributes,
 1;
 =head1 SYNOPSIS
 
-See L<http://help.yahoo.com/l/us/yahoo/amp/webservices/reference/data/> for documentation of the various data objects.
+See L<http://help.yahoo.com/l/us/yahoo/apt/webservices/reference/data/> for documentation of the various data objects.
 
 
 =cut
@@ -58,11 +61,16 @@ Creates a new instance
     ID
     accountID
     adGroupID
+    createTimestamp
+    discounts
     endDate
     guaranteedSettings
+    lastUpdateTimestamp
     nonGuaranteedSettings
     startDate
     status
+    transferedFromID
+    transferedToID
 
 =back
 
@@ -70,8 +78,6 @@ Creates a new instance
 
 =over 8
 
-    createTimestamp
-    lastUpdateTimestamp
 
 =back
 
