@@ -1,5 +1,5 @@
 package Yahoo::Marketing::APT::PlacementGuaranteedSettings;
-# Copyright (c) 2008 Yahoo! Inc.  All rights reserved.  
+# Copyright (c) 2009 Yahoo! Inc.  All rights reserved.  
 # The copyrights to the contents of this file are licensed under the Perl Artistic License (ver. 15 Aug 1997) 
 
 use strict; use warnings;
@@ -48,7 +48,7 @@ __PACKAGE__->mk_accessors( __PACKAGE__->_user_setable_attributes,
 1;
 =head1 SYNOPSIS
 
-See L<http://help.yahoo.com/l/us/yahoo/amp/webservices/reference/data/> for documentation of the various data objects.
+See L<http://help.yahoo.com/l/us/yahoo/apt/webservices/reference/data/> for documentation of the various data objects.
 
 
 =cut
@@ -74,12 +74,13 @@ Creates a new instance
     deliveryModel
     impressionGoal
     inventorySearchFilter
+    networkID
     price
     priceDate
     revenueCategory
     revenueModel
     sectionIDs
-    targetDescriptor
+    siteID
 
 =back
 
