@@ -1,6 +1,6 @@
-package Yahoo::Marketing::Test::RateAdjustmentResponse;
-# Copyright (c) 2008 Yahoo! Inc.  All rights reserved.
-# The copyrights to the contents of this file are licensed under the Perl Artistic License (ver. 15 Aug 1997)
+package Yahoo::Marketing::APT::Test::RateAdjustmentResponse;
+# Copyright (c) 2009 Yahoo! Inc.  All rights reserved.  
+# The copyrights to the contents of this file are licensed under the Perl Artistic License (ver. 15 Aug 1997) 
 
 use strict; use warnings;
 
@@ -12,10 +12,10 @@ use Yahoo::Marketing::APT::RateAdjustmentResponse;
 sub test_can_create_rate_adjustment_response_and_set_all_fields : Test(4) {
 
     my $rate_adjustment_response = Yahoo::Marketing::APT::RateAdjustmentResponse->new
-	                                              ->errors( 'errors' )
-                                                      ->operationSucceeded( 'operation succeeded' )
-                                                      ->rateAdjustment( 'rate adjustment' )
-                               	                      ;
+                                                                           ->errors( 'errors' )
+                                                                           ->operationSucceeded( 'operation succeeded' )
+                                                                           ->rateAdjustment( 'rate adjustment' )
+                   ;
 
     ok( $rate_adjustment_response );
 
