@@ -1,5 +1,5 @@
 package Yahoo::Marketing::APT::Test::TargetingAttributeValue;
-# Copyright (c) 2008 Yahoo! Inc.  All rights reserved.  
+# Copyright (c) 2009 Yahoo! Inc.  All rights reserved.  
 # The copyrights to the contents of this file are licensed under the Perl Artistic License (ver. 15 Aug 1997) 
 
 use strict; use warnings;
@@ -9,7 +9,7 @@ use Test::More;
 
 use Yahoo::Marketing::APT::TargetingAttributeValue;
 
-sub test_can_create_targeting_attribute_value_and_set_all_fields : Test(7) {
+sub test_can_create_targeting_attribute_value_and_set_all_fields : Test(6) {
 
     my $targeting_attribute_value = Yahoo::Marketing::APT::TargetingAttributeValue->new
                                                                              ->ID( 'id' )
@@ -17,7 +17,6 @@ sub test_can_create_targeting_attribute_value_and_set_all_fields : Test(7) {
                                                                              ->name( 'name' )
                                                                              ->parentID( 'parent id' )
                                                                              ->type( 'type' )
-                                                                             ->value( 'value' )
                    ;
 
     ok( $targeting_attribute_value );
@@ -27,7 +26,6 @@ sub test_can_create_targeting_attribute_value_and_set_all_fields : Test(7) {
     is( $targeting_attribute_value->name, 'name', 'can get name' );
     is( $targeting_attribute_value->parentID, 'parent id', 'can get parent id' );
     is( $targeting_attribute_value->type, 'type', 'can get type' );
-    is( $targeting_attribute_value->value, 'value', 'can get value' );
 
 };
 
